2021-12-15 Version: 1.1.6
- Add Tag Api.

2021-11-26 Version: 1.1.5
- Add Deploy Api.

2021-11-26 Version: 1.1.4
- Add Deploy Api.

2021-11-25 Version: 1.1.2
- Add Deploy Api.

2021-11-17 Version: 1.0.4
- Add PipelineValidate API.

2021-09-27 Version: 1.0.3
- Add roleId for result.

2021-09-02 Version: 1.0.1
- Init.

2021-08-31 Version: 1.0.0
- Init.

